@@ -1,22 +1,23 @@
 use extendr_api::prelude::*;
 use tokenizers as tk;
 
+#[extendr]
 pub struct RPostProcessor(pub tk::PostProcessorWrapper);
 
 #[extendr]
 impl RPostProcessor {
     pub fn new(post_processor: Robj) -> extendr_api::Result<Self> {
         if post_processor.inherits("RPostProcessorByteLevel") {
-            unsafe {
-                let ptr = post_processor.external_ptr_addr() as *mut RPostProcessorByteLevel;
-                Ok(RPostProcessor((*ptr).0.clone().into()))
-            }
+            Ok(RPostProcessor(
+                <&RPostProcessorByteLevel>::try_from(&post_processor)?.0.clone().into(),
+            ))
         } else {
             Err(Error::EvalError("Unsupported post_processor".into()))
         }
     }
 }
 
+#[extendr]
 struct RPostProcessorByteLevel(tk::processors::byte_level::ByteLevel);
 
 #[extendr]
